@@ -1,18 +1,18 @@
 package Catmandu::ArXiv;
 
-our $VERSION = '0.022';
+our $VERSION = '0.023';
 
 =head1 NAME
 
 Catmandu::ArXiv - Catmandu modules for working with ArXiv data.
 
-=head1 STATUS
+=begin markdown
 
-<p>
-<a href="https://travis-ci.org/LibreCat/Catmandu-ArXiv"><img src="https://travis-ci.org/LibreCat/Catmandu-ArXiv.svg?branch=master" alt="build status" /></a>
-<a href="https://coveralls.io/r/LibreCat/Catmandu-ArXiv/"><img src="https://coveralls.io/repos/LibreCat/Catmandu-ArXiv/badge.png?branch=master" alt="coverage status" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Catmandu-ArXiv"><img src="http://cpants.cpanauthors.org/dist/Catmandu-ArXiv.png" alt="kwalitee score" /></a>
-</p>
+[![Build Status](https://travis-ci.org/LibreCat/Catmandu-ArXiv.svg?branch=master)](https://travis-ci.org/LibreCat/Catmandu-ArXiv)
+[![Coverage](https://coveralls.io/repos/LibreCat/Catmandu-ArXiv/badge.png?branch=master)](https://coveralls.io/r/LibreCat/Catmandu-ArXiv)
+[![CPANTS kwalitee](http://cpants.cpanauthors.org/dist/Catmandu-ArXiv.png)](http://cpants.cpanauthors.org/dist/Catmandu-ArXiv)
+
+=end markdown
 
 =head1 MODULES
 
